@@ -10,6 +10,7 @@ from django.db.models.fields.reverse_related import ForeignObjectRel
 from django.forms.models import _get_foreign_key
 
 from .common import settings
+from .helpers import AnnotationDescriptor
 from .orm_fields import (
     _AGGREGATES,
     _FUNC_MAP,
@@ -17,6 +18,7 @@ from .orm_fields import (
     _OPEN_IN_ADMIN,
     OrmAdminField,
     OrmAggregateField,
+    OrmAnnotatedField,
     OrmCalculatedField,
     OrmConcreteField,
     OrmFkField,
@@ -53,12 +55,12 @@ _FIELD_MAP = {
 
 
 def _get_all_admin_fields(request):
-    request.data_browser = {"calculated_fields": set()}
+    request.data_browser = {"calculated_fields": set(), "fields": set()}
 
     def from_fieldsets(admin, all_):
         auth_user_compat = settings.DATA_BROWSER_AUTH_USER_COMPAT
         if auth_user_compat and isinstance(admin, UserAdmin):
-            obj = admin.model()  # we want the admin change field sets, not the add ones
+            obj = admin.model()  # get the change fieldsets, not the add ones
         else:
             obj = None
 
@@ -105,7 +107,57 @@ def _get_all_admin_fields(request):
     return model_admins, all_admin_fields
 
 
-def _get_fields_for_model(model, model_admins, admin_fields):
+def _get_calculated_field(request, field_name, model_name, model, admin, model_fields):
+    field_func = getattr(admin, field_name, None)
+    if isinstance(field_func, AnnotationDescriptor):
+        admin_order_field = field_func.admin_order_field
+        qs = admin_get_queryset(admin, request, [field_name])
+
+        annotation = qs.query.annotations.get(admin_order_field)
+        if not annotation:  # pragma: no cover
+            raise Exception(
+                f"Can't find annotation '{admin_order_field}' for {admin}.{field_name}"
+            )
+
+        field_type = getattr(annotation, "output_field", None)
+        if not field_type:  # pragma: no cover
+            raise Exception(
+                f"Annotation '{admin_order_field}' for {admin}.{field_name} doesn't specify 'output_field'"
+            )
+
+        type_ = _get_field_type(model, admin_order_field, field_type)
+        if type_:  # pragma: no branch
+            return OrmAnnotatedField(
+                model_name=model_name,
+                name=field_name,
+                pretty_name=field_name,
+                type_=type_,
+                field_type=field_type,
+                admin=admin,
+                admin_order_field=admin_order_field,
+            )
+    else:
+        return OrmCalculatedField(
+            model_name=model_name, name=field_name, pretty_name=field_name, admin=admin
+        )
+
+
+def _get_field_type(model, field_name, field):
+    if field.__class__ in _FIELD_MAP:
+        return _FIELD_MAP[field.__class__]
+
+    for django_type, field_type in _FIELD_MAP.items():
+        if isinstance(field, django_type):
+            return field_type
+
+    if settings.DEBUG:  # pragma: no cover
+        logging.getLogger(__name__).warning(
+            f"DDB {model.__name__}.{field_name} unsupported type {type(field).__name__}"
+        )
+    return None
+
+
+def _get_fields_for_model(request, model, admin, admin_fields):
     fields = {}
 
     model_name = get_model_name(model)
@@ -126,18 +178,11 @@ def _get_fields_for_model(model, model_admins, admin_fields):
                     rel_name=get_model_name(field.related_model),
                 )
         elif isinstance(field, type(None)):
-            fields[field_name] = OrmCalculatedField(
-                model_name=model_name, name=field_name, pretty_name=field_name
+            fields[field_name] = _get_calculated_field(
+                request, field_name, model_name, model, admin, model_fields
             )
         else:
-            if field.__class__ in _FIELD_MAP:
-                field_type = _FIELD_MAP[field.__class__]
-            else:
-                for django_type, field_type in _FIELD_MAP.items():
-                    if isinstance(field, django_type):
-                        break
-                else:
-                    field_type = None
+            field_type = _get_field_type(model, field_name, field)
 
             if field_type:
                 fields[field_name] = OrmConcreteField(
@@ -146,13 +191,8 @@ def _get_fields_for_model(model, model_admins, admin_fields):
                     pretty_name=field_name,
                     type_=field_type,
                 )
-            else:  # pragma: no cover
-                if settings.DEBUG:
-                    logging.getLogger(__name__).warning(
-                        f"{model.__name__}.{field_name} unsupported type {type(field).__name__}"
-                    )
 
-    return OrmModel(fields=fields, admin=model_admins[model])
+    return OrmModel(fields=fields, admin=admin)
 
 
 def _get_fields_for_type(type_):
@@ -169,7 +209,9 @@ def _get_fields_for_type(type_):
 def get_models(request):
     model_admins, admin_fields = _get_all_admin_fields(request)
     models = {
-        get_model_name(model): _get_fields_for_model(model, model_admins, admin_fields)
+        get_model_name(model): _get_fields_for_model(
+            request, model, model_admins[model], admin_fields
+        )
         for model in admin_fields
     }
     types = {type_.name: _get_fields_for_type(type_) for type_ in TYPES.values()}
@@ -233,19 +275,17 @@ def _rows_sub_query(bound_query):
 
 
 def _get_results(request, bound_query, orm_models):
+    all_fields = {f.queryset_path: f for f in bound_query.bound_fields}
+    all_fields.update({f.queryset_path: f for f in bound_query.bound_filters})
+
     admin = orm_models[bound_query.model_name].admin
-    qs = admin.get_queryset(request)
+    qs = admin_get_queryset(admin, request, {f.split("__")[0] for f in all_fields})
 
-    # functions
-    qs = qs.annotate(
-        **dict(
-            field.function_clause
-            for field in bound_query.bound_fields + bound_query.bound_filters
-            if field.function_clause
-        )
-    )
+    # sql functions and qs annotations
+    for field in all_fields.values():
+        qs = field.annotate(request, qs)
 
-    # filter normal and function fields
+    # filter normal and sql function fields (aka __date)
     for filter_ in bound_query.valid_filters:
         if filter_.orm_bound_field.filter_:
             qs = _filter(qs, filter_, filter_.orm_bound_field.queryset_path)
@@ -293,9 +333,12 @@ def _get_results(request, bound_query, orm_models):
     return list(qs[: bound_query.limit])
 
 
-def get_results(request, bound_query, orm_models):
-    request.data_browser = {"calculated_fields": set()}
+def admin_get_queryset(admin, request, fields=()):
+    request.data_browser = {"calculated_fields": set(fields), "fields": set(fields)}
+    return admin.get_queryset(request)
 
+
+def get_results(request, bound_query, orm_models):
     if not bound_query.fields:
         return {"rows": [], "cols": [], "body": []}
 
@@ -322,8 +365,9 @@ def get_results(request, bound_query, orm_models):
     cache = {}
     for model_name, pks in to_load.items():
         admin = orm_models[model_name].admin
-        request.data_browser["calculated_fields"] = loading_for[model_name]
-        cache[model_name] = admin.get_queryset(request).in_bulk(pks)
+        cache[model_name] = admin_get_queryset(
+            admin, request, loading_for[model_name]
+        ).in_bulk(pks)
 
     # dump out the results
     def format_table(fields, data):
@@ -332,11 +376,9 @@ def get_results(request, bound_query, orm_models):
             if row:
                 res_row = {}
                 for field in fields:
-                    value = row[field.path_str]
+                    value = row[field.queryset_path]
                     if field.model_name:
-                        admin = orm_models[field.model_name].admin
-                        obj = cache[field.model_name].get(value)
-                        value = obj, admin
+                        value = cache[field.model_name].get(value)
                     res_row[field.path_str] = field.format(value)
                 results.append(res_row)
             else:
@@ -344,7 +386,9 @@ def get_results(request, bound_query, orm_models):
         return results
 
     def get_fields(row, fields):
-        return tuple((field.path_str, row[field.queryset_path]) for field in fields)
+        return tuple(
+            (field.queryset_path, row[field.queryset_path]) for field in fields
+        )
 
     col_keys = {}
     for row in cols_res:
