@@ -3,7 +3,7 @@ from typing import Sequence, Tuple
 
 from django.contrib.admin.options import BaseModelAdmin
 from django.db import models
-from django.db.models import functions
+from django.db.models import OuterRef, Subquery, functions
 from django.db.models.functions import Cast
 from django.urls import reverse
 
@@ -83,10 +83,10 @@ def get_model_name(model, sep="."):
 @dataclass
 class OrmBoundField:
     field: "OrmBaseField"
+    previous: "OrmBoundField"
     full_path: Sequence[str]
     pretty_path: Sequence[str]
     queryset_path: str = None
-    function_clause: Tuple[str, models.Func] = None
     aggregate_clause: Tuple[str, models.Func] = None
     filter_: bool = False
     having: bool = False
@@ -96,17 +96,20 @@ class OrmBoundField:
     def path_str(self):
         return s(self.full_path)
 
-    @property
-    def type_(self):
-        return self.field.type_
-
     @property
     def group_by(self):
         return self.field.can_pivot
 
+    def annotate(self, request, qs):
+        return qs
+
     def __getattr__(self, name):
         return getattr(self.field, name)
 
+    @classmethod
+    def blank(cls):
+        return cls(field=None, previous=None, full_path=[], pretty_path=[])
+
 
 @dataclass
 class OrmModel:
@@ -127,6 +130,7 @@ class OrmBaseField:
     concrete: bool = False
     rel_name: str = None
     can_pivot: bool = False
+    admin: object = None
 
     def __post_init__(self):
         if not self.type_:
@@ -143,10 +147,11 @@ class OrmFkField(OrmBaseField):
         super().__init__(model_name, name, pretty_name, rel_name=rel_name)
 
     def bind(self, previous):
-        previous = previous or OrmBoundField(None, full_path=[], pretty_path=[])
+        previous = previous or OrmBoundField.blank()
         full_path = previous.full_path + [self.name]
         return OrmBoundField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
         )
@@ -167,10 +172,11 @@ class OrmConcreteField(OrmBaseField):
         )
 
     def bind(self, previous):
-        previous = previous or OrmBoundField(None, full_path=[], pretty_path=[])
+        previous = previous or OrmBoundField.blank()
         full_path = previous.full_path + [self.name]
         return OrmBoundField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(full_path),
@@ -179,31 +185,30 @@ class OrmConcreteField(OrmBaseField):
 
 
 class OrmCalculatedField(OrmBaseField):
-    def __init__(self, model_name, name, pretty_name):
+    def __init__(self, model_name, name, pretty_name, admin):
         super().__init__(
-            model_name, name, pretty_name, type_=StringType, can_pivot=True
+            model_name, name, pretty_name, type_=StringType, can_pivot=True, admin=admin
         )
 
     def bind(self, previous):
-        previous = previous or OrmBoundField(None, full_path=[], pretty_path=[])
+        previous = previous or OrmBoundField.blank()
         full_path = previous.full_path + [self.name]
         return OrmBoundField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(previous.full_path + ["id"]),
             model_name=self.model_name,
         )
 
-    def format(self, value):
-        obj, admin = value
-
+    def format(self, obj):
         if obj is None:
             return None
 
-        if hasattr(admin, self.name):
+        if hasattr(self.admin, self.name):
             # admin callable
-            func = getattr(admin, self.name)
+            func = getattr(self.admin, self.name)
             try:
                 return func(obj)
             except Exception as e:
@@ -217,6 +222,60 @@ class OrmCalculatedField(OrmBaseField):
                 return str(e)
 
 
+class OrmBoundAnnotatedField(OrmBoundField):
+    def annotate(self, request, qs):
+        from .orm import admin_get_queryset
+
+        return qs.annotate(
+            **{
+                self.queryset_path: Subquery(
+                    admin_get_queryset(self.admin, request, [self.name])
+                    .filter(pk=OuterRef(s(self.previous.full_path + ["id"])))
+                    .values(self.admin_order_field)[:1],
+                    output_field=self.field_type,
+                )
+            }
+        )
+
+
+class OrmAnnotatedField(OrmBaseField):
+    def __init__(
+        self, model_name, name, pretty_name, type_, field_type, admin, admin_order_field
+    ):
+        super().__init__(
+            model_name,
+            name,
+            pretty_name,
+            type_=type_,
+            can_pivot=True,
+            admin=admin,
+            concrete=True,
+        )
+        self.field_type = field_type
+        self.admin_order_field = admin_order_field
+
+    def bind(self, previous):
+        if previous:
+            full_path = previous.full_path + [self.name]
+            return OrmBoundAnnotatedField(
+                field=self,
+                previous=previous,
+                full_path=full_path,
+                pretty_path=previous.pretty_path + [self.pretty_name],
+                queryset_path=f"ddb_{s(full_path)}",
+                filter_=True,
+            )
+        else:
+            return OrmBoundField(
+                field=self,
+                previous=OrmBoundField.blank(),
+                full_path=[self.name],
+                pretty_path=[self.pretty_name],
+                queryset_path=self.name,
+                filter_=True,
+            )
+
+
 class OrmAdminField(OrmBaseField):
     def __init__(self, model_name):
         super().__init__(
@@ -224,19 +283,18 @@ class OrmAdminField(OrmBaseField):
         )
 
     def bind(self, previous):
-        previous = previous or OrmBoundField(None, full_path=[], pretty_path=[])
+        previous = previous or OrmBoundField.blank()
         full_path = previous.full_path + [self.name]
         return OrmBoundField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(previous.full_path + ["id"]),
             model_name=self.model_name,
         )
 
-    def format(self, value):
-        obj, admin = value
-
+    def format(self, obj):
         if obj is None:
             return None
 
@@ -257,6 +315,7 @@ class OrmAggregateField(OrmBaseField):
         agg = _AGG_MAP[self.aggregate](s(previous.full_path))
         return OrmBoundField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(full_path),
@@ -265,6 +324,17 @@ class OrmAggregateField(OrmBaseField):
         )
 
 
+class OrmBoundFunctionField(OrmBoundField):
+    def annotate(self, request, qs):
+        return qs.annotate(
+            **{
+                self.queryset_path: _FUNC_MAP[self.function][0](
+                    s(self.previous.full_path)
+                )
+            }
+        )
+
+
 class OrmFunctionField(OrmBaseField):
     def __init__(self, model_name, name, type_):
         super().__init__(
@@ -275,12 +345,11 @@ class OrmFunctionField(OrmBaseField):
     def bind(self, previous):
         assert previous
         full_path = previous.full_path + [self.name]
-        func = _FUNC_MAP[self.function][0](s(previous.full_path))
-        return OrmBoundField(
+        return OrmBoundFunctionField(
             field=self,
+            previous=previous,
             full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=s(full_path),
-            function_clause=(s(full_path), func),
             filter_=True,
         )
