@@ -45,7 +45,7 @@ def _get_query_data(bound_query):
             for field in bound_query.fields
         ],
         "model": bound_query.model_name,
-        "limit": str(bound_query.limit),
+        "limit": bound_query.limit,
     }
 
 
