@@ -500,6 +500,13 @@ snapshots["test_query_html config"] = {
                     "prettyName": "admin",
                     "type": "html",
                 },
+                "andrew": {
+                    "canPivot": True,
+                    "concrete": True,
+                    "model": None,
+                    "prettyName": "andrew",
+                    "type": "string",
+                },
                 "bob": {
                     "canPivot": True,
                     "concrete": False,
@@ -536,7 +543,7 @@ snapshots["test_query_html config"] = {
                     "type": "string",
                 },
             },
-            "sortedFields": ["id", "admin", "bob", "city", "fred", "tom"],
+            "sortedFields": ["id", "admin", "andrew", "bob", "city", "fred", "tom"],
         },
         "tests.InAdmin": {
             "fields": {
@@ -679,6 +686,13 @@ snapshots["test_query_html config"] = {
                     "prettyName": "admin",
                     "type": "html",
                 },
+                "annotated": {
+                    "canPivot": True,
+                    "concrete": True,
+                    "model": None,
+                    "prettyName": "annotated",
+                    "type": "string",
+                },
                 "created_time": {
                     "canPivot": True,
                     "concrete": True,
@@ -753,6 +767,7 @@ snapshots["test_query_html config"] = {
             "sortedFields": [
                 "id",
                 "admin",
+                "annotated",
                 "created_time",
                 "default_sku",
                 "is_onsale",
@@ -1039,7 +1054,7 @@ snapshots["test_query_query query"] = {
             "value": "0",
         },
     ],
-    "limit": "1000",
+    "limit": 1000,
     "model": "tests.Product",
 }
 
@@ -1935,6 +1950,13 @@ snapshots["test_query_ctx config"] = {
                     "prettyName": "admin",
                     "type": "html",
                 },
+                "andrew": {
+                    "canPivot": True,
+                    "concrete": True,
+                    "model": None,
+                    "prettyName": "andrew",
+                    "type": "string",
+                },
                 "bob": {
                     "canPivot": True,
                     "concrete": False,
@@ -1971,7 +1993,7 @@ snapshots["test_query_ctx config"] = {
                     "type": "string",
                 },
             },
-            "sortedFields": ["id", "admin", "bob", "city", "fred", "tom"],
+            "sortedFields": ["id", "admin", "andrew", "bob", "city", "fred", "tom"],
         },
         "tests.InAdmin": {
             "fields": {
@@ -2114,6 +2136,13 @@ snapshots["test_query_ctx config"] = {
                     "prettyName": "admin",
                     "type": "html",
                 },
+                "annotated": {
+                    "canPivot": True,
+                    "concrete": True,
+                    "model": None,
+                    "prettyName": "annotated",
+                    "type": "string",
+                },
                 "created_time": {
                     "canPivot": True,
                     "concrete": True,
@@ -2188,6 +2217,7 @@ snapshots["test_query_ctx config"] = {
             "sortedFields": [
                 "id",
                 "admin",
+                "annotated",
                 "created_time",
                 "default_sku",
                 "is_onsale",
@@ -2555,7 +2585,7 @@ snapshots["test_query_json data"] = {
         },
     ],
     "length": 2,
-    "limit": "1000",
+    "limit": 1000,
     "model": "tests.Product",
     "rows": [
         {"name": "a", "size": 1.0, "size_unit": "g"},
@@ -2606,7 +2636,7 @@ snapshots["test_query_json_pivot data"] = {
     "filterErrors": [],
     "filters": [],
     "length": 3,
-    "limit": "1000",
+    "limit": 1000,
     "model": "tests.Product",
     "rows": [{"created_time__year": 2020.0}, {"created_time__year": 2021.0}],
 }
